
"""\
This file is an installation script for this cleanskin skin.  It's meant
to be used as an External Method.  To use, add an external method to the
root of the CMF Site that you want ZPT skins registered in with the
configuration:

 id: install_clean
 title: Install Clean skin
 module name: cleanskin.Install
 function name: install

Then go to the management screen for the newly added external method
and click the 'Test' tab.  The install function will execute and give
information about the steps it took to register and install the 
clean skin into the CMF Site instance. 
"""
from Products.CMFCore.DirectoryView import addDirectoryViews
from Products.CMFCore.utils import getToolByName
from Products.cleanskin import cleanskin_globals

from cStringIO import StringIO
import string

CLEANSKIN_SKINS_DIRS = ( 'cleanskin', )

def install(self):
    """
        Register cleanskin with portal_skins and friends.
    """
    out = StringIO()
    skinstool = getToolByName(self, 'portal_skins')

    for dir_view in CLEANSKIN_SKINS_DIRS:
        if dir_view in skinstool.objectIds():
            skinstool._delObject( dir_view )

    try:
        addDirectoryViews( skinstool, 'skins', cleanskin_globals )
    except:
        pass
    out.write( "Added cleanskin directory views to portal_skins\n" )

    #
    #   Add a new skin, 'cleanskin', copying 'ZPT', if it exists, and then
    #   add our directories only to it.
    #
    ZPT_skin = skinstool.getSkinPath( 'Basic' )

    if ZPT_skin is None:
        out.write( "No ZPT skin found!" )
    
    else:

        if skinstool.getSkinPath( 'cleanskin' ) is None:

            path = map( string.strip, string.split( ZPT_skin,',' ) )
            for skindir in CLEANSKIN_SKINS_DIRS:
                try:
                    path.insert( 1, skindir )
                except ValueError:
                    path.append( skindir )
                        
            path = string.join( path, ', ' )
            skinstool.addSkinSelection( 'cleanskin', path )
            out.write( "Added cleanskin skin\n" )
        
        else:
            out.write( "The skin 'cleanskin' already exists\n" )

    return out.getvalue()

